pub struct OSLogMessageComponent { /* private fields */ }Expand description
The message arguments for a particular entry. There is one component for each placeholder in the formatString plus one component for any text after the last placeholder.
See also Apple’s documentation
Implementations
Sourceimpl OSLogMessageComponent
impl OSLogMessageComponent
Sourcepub unsafe fn formatSubstring(&self) -> Retained<NSString>
pub unsafe fn formatSubstring(&self) -> Retained<NSString>
The text immediately preceding a placeholder. This can be an empty string if there is nothing between two placeholders, or between the placeholder and the bounds of the string.
Sourcepub unsafe fn placeholder(&self) -> Retained<NSString>
pub unsafe fn placeholder(&self) -> Retained<NSString>
The placeholder text. Is empty for is the last component.
Sourcepub unsafe fn argumentCategory(&self) -> OSLogMessageComponentArgumentCategory
pub unsafe fn argumentCategory(&self) -> OSLogMessageComponentArgumentCategory
The type of argument corresponding to the placeholder; see OSLogMessageComponentArgumentCategory.
Sourcepub unsafe fn argumentDataValue(&self) -> Option<Retained<NSData>>
pub unsafe fn argumentDataValue(&self) -> Option<Retained<NSData>>
The argument as a sequence of bytes. Can be nil if the argument cannot be decoded (for example, it could be redacted), or if this is the last component.
Sourcepub unsafe fn argumentDoubleValue(&self) -> c_double
pub unsafe fn argumentDoubleValue(&self) -> c_double
The argument as a double-precision floating point number; the value is undefined if the argument cannot be decoded or if this is the last component.
Sourcepub unsafe fn argumentInt64Value(&self) -> i64
pub unsafe fn argumentInt64Value(&self) -> i64
The argument as a 64-bit signed integer; the value is undefined if it cannot be decoded or if this is the last component.
Sourcepub unsafe fn argumentNumberValue(&self) -> Option<Retained<NSNumber>>
pub unsafe fn argumentNumberValue(&self) -> Option<Retained<NSNumber>>
The argument as a number. Can be nil if the argument cannot be decoded (for example, it could be redacted), or if this is the last component.
Sourcepub unsafe fn argumentStringValue(&self) -> Option<Retained<NSString>>
pub unsafe fn argumentStringValue(&self) -> Option<Retained<NSString>>
The argument as a string. Can be nil if the argument cannot be decoded (for example, it could be redacted), or if this is the last component.
Sourcepub unsafe fn argumentUInt64Value(&self) -> u64
pub unsafe fn argumentUInt64Value(&self) -> u64
The argument as a 64-bit unsigned integer; the value is undefined if the argument cannot be decoded or if this is the last component.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for OSLogMessageComponent
impl AsRef<AnyObject> for OSLogMessageComponent
Sourceimpl AsRef<NSObject> for OSLogMessageComponent
impl AsRef<NSObject> for OSLogMessageComponent
Sourceimpl Borrow<AnyObject> for OSLogMessageComponent
impl Borrow<AnyObject> for OSLogMessageComponent
Sourceimpl Borrow<NSObject> for OSLogMessageComponent
impl Borrow<NSObject> for OSLogMessageComponent
Sourceimpl ClassType for OSLogMessageComponent
impl ClassType for OSLogMessageComponent
Sourceconst NAME: &'static str = "OSLogMessageComponent"
const NAME: &'static str = "OSLogMessageComponent"
Sourcetype ThreadKind = <<OSLogMessageComponent as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<OSLogMessageComponent as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for OSLogMessageComponent
impl Debug for OSLogMessageComponent
Sourceimpl Deref for OSLogMessageComponent
impl Deref for OSLogMessageComponent
Sourceimpl Hash for OSLogMessageComponent
impl Hash for OSLogMessageComponent
Sourceimpl Message for OSLogMessageComponent
impl Message for OSLogMessageComponent
Sourceimpl NSObjectProtocol for OSLogMessageComponent
impl NSObjectProtocol for OSLogMessageComponent
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref