#[repr(transparent)]pub struct OSLogMessageComponentArgumentCategory(pub NSInteger);Expand description
The kind of data corresponding to an argument in a message payload, like the number associated with a “%d” placeholder. This value can be undefined if the argument data cannot be decoded; for example, it may be redacted.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations