#[repr(transparent)]pub struct OSLogStoreScope(pub NSInteger);Expand description
Create a store to a subset of the libtrace entries.
“System” scope indicates the entire system; i.e., all logs. Entries can be retrieved for the current calling process, i.e., matching pid.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl OSLogStoreScope
impl OSLogStoreScope
pub const System: Self
pub const CurrentProcessIdentifier: Self