OSLogEntryFromProcess

Trait OSLogEntryFromProcess 

pub unsafe trait OSLogEntryFromProcess {
    // Provided methods
    unsafe fn activityIdentifier(&self) -> u64
       where Self: Sized + Message { ... }
    unsafe fn process(&self) -> Retained<NSString>
       where Self: Sized + Message { ... }
    unsafe fn processIdentifier(&self) -> pid_t
       where Self: Sized + Message { ... }
    unsafe fn sender(&self) -> Retained<NSString>
       where Self: Sized + Message { ... }
    unsafe fn threadIdentifier(&self) -> u64
       where Self: Sized + Message { ... }
}
Entry subclasses conforming to this protocol represent data that are generated from a process; they have metadata about the originator.

See also Apple’s documentation

Provided Methods

unsafe fn activityIdentifier(&self) -> u64
where Self: Sized + Message,

The activity ID associated with the entry.

unsafe fn process(&self) -> Retained<NSString>
where Self: Sized + Message,

The name of the process that made the entry.

unsafe fn processIdentifier(&self) -> pid_t
where Self: Sized + Message,

Available on crate feature libc only.

The pid of the process that made the entry.

unsafe fn sender(&self) -> Retained<NSString>
where Self: Sized + Message,

The name of the binary image that made the entry.

unsafe fn threadIdentifier(&self) -> u64
where Self: Sized + Message,

The tid of the thread that made the entry.