OSLogEntryWithPayload

Trait OSLogEntryWithPayload 

pub unsafe trait OSLogEntryWithPayload {
    // Provided methods
    unsafe fn category(&self) -> Retained<NSString>
       where Self: Sized + Message { ... }
    unsafe fn components(&self) -> Retained<NSArray<OSLogMessageComponent>>
       where Self: Sized + Message { ... }
    unsafe fn formatString(&self) -> Retained<NSString>
       where Self: Sized + Message { ... }
    unsafe fn subsystem(&self) -> Retained<NSString>
       where Self: Sized + Message { ... }
}
Entry subclasses conforming to this protocol represent entries that were made using a handle and a format string.

See also Apple’s documentation

Provided Methods

unsafe fn category(&self) -> Retained<NSString>
where Self: Sized + Message,

The category from the os_log_t handle used.

unsafe fn components(&self) -> Retained<NSArray<OSLogMessageComponent>>
where Self: Sized + Message,

An array of the various parts of the composed message.

unsafe fn formatString(&self) -> Retained<NSString>
where Self: Sized + Message,

The format string used.

unsafe fn subsystem(&self) -> Retained<NSString>
where Self: Sized + Message,

The subsystem of the os_log_t handle used.