#[repr(transparent)]pub struct OSLogEntryStoreCategory(pub NSInteger);Expand description
A classification of how the entry was to be stored and rotated at the point when it was created.
The unified logging system keeps entries in one of two places: a ring buffer in memory and a persisted data store. Entries are rotated out of both places to free up resources. This rotation is not strictly aligned with entries’ timestamps — in particular, they can be rotated in bulk, and they are rotated according to a series of heuristics that take into account space, time, and how the entries were classified.
This entry was generated as information about the other entries or about the sequence of entries as a whole.
This entry was not intended to be long-lived and was captured in the ring buffer.
The entry was intended to be persisted in a filesystem-backed data store and kept mainly based on the amount of space available.
The entry was tagged with a hint indicating that the system should try to preserve it for a certain amount of time. It was persisted in the filesystem-backed data store, and rotation of these entries was based on both time and space considerations.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations