pub unsafe trait OSLogEntryFromProcess {
// Provided methods
unsafe fn activityIdentifier(&self) -> u64
where Self: Sized + Message { ... }
unsafe fn process(&self) -> Retained<NSString>
where Self: Sized + Message { ... }
unsafe fn processIdentifier(&self) -> pid_t
where Self: Sized + Message { ... }
unsafe fn sender(&self) -> Retained<NSString>
where Self: Sized + Message { ... }
unsafe fn threadIdentifier(&self) -> u64
where Self: Sized + Message { ... }
}Expand description
Entry subclasses conforming to this protocol represent data that are generated from a process; they have metadata about the originator.
See also Apple’s documentation
Provided Methods
Sourceunsafe fn activityIdentifier(&self) -> u64
unsafe fn activityIdentifier(&self) -> u64
The activity ID associated with the entry.
Sourceunsafe fn processIdentifier(&self) -> pid_t
Available on crate feature libc only.
unsafe fn processIdentifier(&self) -> pid_t
libc only.The pid of the process that made the entry.
Sourceunsafe fn sender(&self) -> Retained<NSString>
unsafe fn sender(&self) -> Retained<NSString>
The name of the binary image that made the entry.
Sourceunsafe fn threadIdentifier(&self) -> u64
unsafe fn threadIdentifier(&self) -> u64
The tid of the thread that made the entry.