pub unsafe trait OSLogEntryWithPayload {
// Provided methods
unsafe fn category(&self) -> Retained<NSString>
where Self: Sized + Message { ... }
unsafe fn components(&self) -> Retained<NSArray<OSLogMessageComponent>>
where Self: Sized + Message { ... }
unsafe fn formatString(&self) -> Retained<NSString>
where Self: Sized + Message { ... }
unsafe fn subsystem(&self) -> Retained<NSString>
where Self: Sized + Message { ... }
}Expand description
Entry subclasses conforming to this protocol represent entries that were made using a handle and a format string.
See also Apple’s documentation
Provided Methods
Sourceunsafe fn components(&self) -> Retained<NSArray<OSLogMessageComponent>>
unsafe fn components(&self) -> Retained<NSArray<OSLogMessageComponent>>
An array of the various parts of the composed message.
Sourceunsafe fn formatString(&self) -> Retained<NSString>
unsafe fn formatString(&self) -> Retained<NSString>
The format string used.